/**
 * 霍兰德
 */

import { TABLENAME } from "../config/dbEnum";
import { QUESTIONTITLE, TESTTYPE } from "../config/enum";
import { selectDataToTableAssociation } from "../data/findData";
import { eccEnumValue } from "../tools/eccEnum";


/**
 * 获取题目
 * @param test_type 题目类型：1. 霍兰德
 * @param chapter 章节
 * 1.霍兰德（一、我感兴趣的活动）2.霍兰德（二、我能完成的活动）3.霍兰德（三、我喜欢的职业）
 * 4.霍兰德（四、我的能力类型简评A）5.霍兰德（四、我的能力类型简评B）
 * @returns 
 */
export async function getQuestion(test_type, chapter) {
    eccEnumValue("获取题目", "test_type", TESTTYPE, test_type);
    eccEnumValue("获取题目", "chapter", QUESTIONTITLE, chapter);


    let selectParam:any = {is_del:0, test_type:1, chapter:1};

    if (test_type) selectParam.test_type = test_type;
    if (chapter) selectParam.chapter = chapter;
    /** includeConf:关联表配置*/
    let includeConf = {};
    includeConf[TABLENAME.题目选项表] = {colum:["option_name", "points"], where:{is_del:0} }; // colum：关联表需要查询的字段，where：关联表查询条件

    /** questionInfo：多表联查*/
    let questionInfo = await selectDataToTableAssociation(TABLENAME.题目表, includeConf, selectParam, ["chapter", "title"]);
    

    // return {};
    return questionInfo;
}



/**
 * 计算霍兰德职业兴趣测试分数并汇总最高三个字母
 * @param answers 用户的答案对象数组
 * @returns 包含测试结果的对象
 */
export function calculateHollandScore(answers: any[]): { topThree: string; scores: Record<string, number> } {
    //初始化分数统计对象
    const scoreCounts = {
        R: 0,// Realistic
        I: 0, // Investigative
        A: 0, // Artistic                
        S: 0, // Social
        E: 0, // Enterprising
        C: 0  // Conventional
    };

    // 遍历用户答案并累加相应类型的分数
    for (const answer of answers) {
        const points = answer.points;
        switch (answer.title) {
            case 'R：实际型活动':
                scoreCounts.R += points;
                break;
            case 'S：社会型活动':
                scoreCounts.S += points;
                break;
            case 'I：研究型活动':
                scoreCounts.I += points;
                break;
            case 'E；事业型活动':
                scoreCounts.E += points;
                break;
            case 'A：艺术型活动':
                scoreCounts.A += points;
                break;
            case 'C：常规型(传统型)活动':
                scoreCounts.C += points;
                break;
            default:
                console.warn(`未知的霍兰德类型: ${answer.type}`);
        }
    }

    //计算最高三个字母分数
    const scoredArray = Object.entries(scoreCounts).map(([key, value]) => ({ type: key, score: value }));
    scoredArray.sort((a, b) => b.score - a.score);

    //获取最高三个字母
    const topThree = scoredArray.slice(0, 3).map(item => item.type).join('');

    //返回结果对象
    return {
        topThree,
        scores: scoreCounts
    };
}


/**
 * 统计并汇总最高三个字母
 * @param scores 分数统计对象
 * @returns 包含统计结果的对象
 */
export function summarizeScores(scores: Record<string, number>): { highestLetter: string; secondHighestLetter: string; thirdHighestLetter: string } {
    const scoredArray = Object.entries(scores).map(([key, value]) => ({ type: key, score: value }));
    scoredArray.sort((a, b) => b.score - a.score);

    //获取最高三个字母
    const highestLetter = scoredArray[0].type;
    const secondHighestLetter = scoredArray[1]?.type || '';
    const thirdHighestLetter = scoredArray[2]?.type || '';

    return {
        highestLetter,
        secondHighestLetter,
        thirdHighestLetter
    };
}


